[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](CODE_OF_CONDUCT.md)
[![PyPI badge](http://img.shields.io/pypi/v/tof.svg)](https://pypi.python.org/pypi/tof)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/tof/badges/version.svg)](https://anaconda.org/conda-forge/tof)
[![License: BSD 3-Clause](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](LICENSE)
[![Try it](https://img.shields.io/badge/try_it_in_your_browser!-8A2BE2)](https://scipp.github.io/toflite/lab/index.html?path=app.ipynb)

# Tof


## About

A simple tool to create time-of-flight chopper cascade diagrams

**Scope:**

- ``tof`` is designed to be simple and lightweight, it will never replace [McStas](https://www.mcstas.org/)
- it assumes all neutrons travel in a straight line
- it does not simulate absorption or scattering effects

## Installation

```sh
python -m pip install tof
```

## Documentation

[https://scipp.github.io/tof/](https://scipp.github.io/tof/)

![example](https://scipp.github.io/tof/_images/demo_13_1.png)
